# Debugging level, 0=errors only, 1=return status, init messages,
#   2=smtp server communication, 3=detailed smtp server communication,
#   4=tracebacks, 5=smtp client communication
DEBUG_LEVEL=3

# Logfile
LOGFILE='/var/log/sagator.log'

# Where is new root path. For example '/var/spool/vscan'
CHROOT='/var/spool/vscan'

# User and group, under which this program runs.
USER,GROUP='vscan','vscan'

# SMTP server host and port. You must define this smtp server
# in postfix without filtering.
SMTP_SERVER=('127.0.0.1',26)

# host and port to listen
BIND_ADDR=('localhost',27)

# statistics collector
COLLECTOR_SERVER=('0.0.0.0',28)

# Quarantine dir, in which are stored viruses and spams.
QUARANTINE_DIR='/tmp/quarantine'

# Scanners
from base import *
from mimeparse import *
from clamav import *
from avg import avg
from nodold import nodold
from sophie import sophie
from spamassassin import spamassassin,spamassassind
from bogofilter import bogofilter
from qsf import qsf
from decompress import decompress
from patterns import *
from stats import status

# Define scanners
SCANNERS=[
  status("Virus",
    # ClamAV
    alternatives(
      stream2mbox(libclam()),
      #mimeparse(libclam()),
      #mimeparse(stream2file(decompress(libclam()))),
      #clamd(['localhost',3310]),
      #clamd('/var/spool/vscan/clamd'),
      #stream2mbox(clamscan(['/usr/bin/clamscan','--stdout','--infected','--disable-summary','-r','--mbox'])),
    ),
    # Simple scanners
    #max_file_size(10),
    #mimeparse(file_type({'exe': 'Executable'})),
    #string_scan(VIR_PATTERNS),
    #regexp_scan({'virname':['___PATTERN___']}),
    #mime_ext(mime_ext.EXECUTABLES),
    # AVG7 for linux
    #mimeparse(s2f(avg())),
    # NODOLD
    #mimeparse(stream2file(nodold(['localhost',8448]))),
    # Sophie
    #mimeparse(s2f(decompress(sophie('/tmp/sophie',CHROOT)))),
    # exec any program
    #s2f(exec_any(['/bin/grep','-q','^TVqQ'],[1],[0])),
  ),
  status("Spam",
    # SpamAssassin
    #alternatives(
      spamassassind(['localhost',783]),
    #  spamassassin(['/usr/bin/spamassassin','-e'])
    #),
    #bogofilter(['/usr/bin/bogofilter','-v']),
    #qsf(['/usr/bin/qsf','-r']),
  )
]

# user defined configurations for --config parameter of sagator or sgscan
# SCANNERS are overwritten by CONFIG["n"], if "--config n" command line
# parameter is used
CONFIG={
  'av': [status("Virus", stream2mbox(libclam()) )],
  'clamd': [status("Virus", clamd(['localhost',3310]) )],
  'decomp': [mimeparse(s2f(decompress(libclam())))],
  'as': [status("Spam", spamassassind(['localhost',783]) )]
}

# Drop emails, which contains viruses or spams.
# Define a regular expression pattern. If this pattern is found
# in reply of scanner, then mail is dropped elsewhere, it is rejected.
DROP='(SPAM|sobig|frethem|lirva|klez|palyh|bugbear|Gibe|Swen)'

# Always send, and do not reject or drop.
# Define a regular expression pattern. If this pattern is found in virname
# mail is sent to recipients always. If it is not set, only clean 
# mails are sent, others are rejected or dropped.
ALWAYS_SEND=''

# If this regular expression is found in virname, mail is not
# quarantined. If this config parameter is not set, all virsuses
# are quarantined.
DONT_QUARANTINE=''

# Send virus reports as ...
REPORT_SENDER='root@localhost'
# Send virus reports to ['...','...']
REPORT_RECIPIENTS=['root@localhost']

# MESSAGE REPORT TEMPLATE FOR ADMIN
ADMIN_REPORT_MSG='''From: %s
To: %s
Subject: ALERT, %s FOUND!

                             VIRUS FOUND!

---------------------------------------------------------------------
SMTP COMMUNICATION:
%s\
---------------------------------------------------------------------
STATUS: %s
QUARANTINED AS: %s
---------------------------------------------------------------------
OUTPUT OF SCANNER:
%s\
---------------------------------------------------------------------
HEADER OF MESSAGE:
%s\
'''

# MESSAGE REPORT TEMPLATE FOR USER
#USER_REPORT_MSG=ADMIN_REPORT_MSG
